@@ -11,7 +11,7 @@ from .core.progress import (
 )
 
 from .core.select_files import (
-    ControllerFiles, AppFileDialog, PreferencesApp,
+    ControllerConfig, AppFileDialog, PreferencesApp,
 )
 
 from .core.observer import (
