@@ -19,7 +19,8 @@ from .observer import (
 from .select_files import (
     PreferencesApp,
     AppFileDialog,
-    ControllerFiles,
+    ControllerConfig,
+    SelectDiskFiles
 )
 from .menu_bar import MenuBar
 from .progress import (
