@@ -2,11 +2,11 @@
 from abc import ABC, abstractmethod
 from enum import Enum
 from typing import List, Dict
-
 from tkinter import ttk
 import tkinter as tk
 from soup_files import LibraryDocs
 from gui_stream.app_ui.core.themes import AppThemes
+from gui_stream.app_ui.core.select_files import SelectDiskFiles
 from gui_stream.app_ui.core.page import ControllerApp
 from gui_stream.app_ui.core.progress import (
     ProgressBarTkIndeterminate,
@@ -14,6 +14,7 @@ from gui_stream.app_ui.core.progress import (
     ProgressBarAdapter,
 )
 
+
 class Orientation(Enum):
     H = 'horizontal'
     V = 'vertical'
@@ -85,20 +86,27 @@ class WidgetRow(WidgetApp):
 
 
 class WidgetFiles(object):
-    def __init__(self, frame: ttk.Frame, *, orientation: Orientation = Orientation.V, controller: ControllerApp):
+
+    def __init__(
+                self, frame: ttk.Frame, *,
+                orientation: Orientation = Orientation.V,
+                controller: ControllerApp,
+                disk_files: SelectDiskFiles,
+            ):
         self.controller: ControllerApp = controller
+        self.select_disk_files: SelectDiskFiles = disk_files
         self.orientation: Orientation = orientation
-        self.frame: ttk.Frame = ttk.Frame(frame)
-        self.frame.pack(expand=True, fill='x')
+        self.frame_files: ttk.Frame = ttk.Frame(frame)
+        self.frame_files.pack(expand=True, fill='x')
         self._PADDING = (6, 8)
         self._WIDTH = 14
         
         self.frame_buttons: ttk.Frame = ttk.Frame(
-            self.frame,
+            self.frame_files,
             style=controller.appTheme.value,
         )
         self.frame_labels: ttk.Frame = ttk.Frame(
-            self.frame,
+            self.frame_files,
             style=AppThemes.LIGHT_PURPLE.value,
         )
         
@@ -115,7 +123,7 @@ class WidgetFiles(object):
         )
         self.lb_outdir = ttk.Label(
             self.frame_labels,
-            text=f'Salvar em: {self.controller.controllerFiles.save_dir.basename()} '
+            text=f'Salvar em: {self.controller.controller_conf.save_dir.basename()} '
         )
         if self.orientation == Orientation.V:
             self.frame_buttons.pack(expand=True, fill='both', padx=1, pady=1)
@@ -143,7 +151,7 @@ class WidgetFiles(object):
         )
         self.lb_img: ttk.Label = ttk.Label(
             self.frame_labels,
-            text=f'Imagens: {self.controller.controllerFiles.num_files_image}'
+            text=f'Imagens: {self.select_disk_files.num_files_image}'
         )
 
         # -----------------------------------------------------------#
@@ -159,7 +167,7 @@ class WidgetFiles(object):
         )
         self.lb_pdf: ttk.Label = ttk.Label(
             self.frame_labels,
-            text=f'PDFs: {self.controller.controllerFiles.num_files_pdf}'
+            text=f'PDFs: {self.select_disk_files.num_files_pdf}'
         )
         self.controller.windowFrames.append(self.frame_buttons)
         self.controller.windowFrames.append(self.frame_labels)
@@ -177,7 +185,7 @@ class WidgetFiles(object):
         )
         self.lb_sheets: ttk.Label = ttk.Label(
             self.frame_labels,
-            text=f'Planilhas: {self.controller.controllerFiles.num_files_sheet}'
+            text=f'Planilhas: {self.select_disk_files.num_files_sheet}'
         )
         
         # -----------------------------------------------------------#
@@ -251,58 +259,61 @@ class WidgetFiles(object):
             self.btn_clear_files.pack(expand=True, fill='both', padx=1, pady=1, side=tk.LEFT)
 
     def add_files_pdf(self):
-        self.controller.controllerFiles.select_files(LibraryDocs.PDF)
+        """
+            Selecinar aquivos com pop-up gráfico, e adicionar os aquivos ao controlador.
+        """
+        self.select_disk_files.select_files(LibraryDocs.PDF)
         self.lb_pdf.config(
-            text=f'PDFs: {self.controller.controllerFiles.num_files_pdf}'
+            text=f'PDFs: {self.select_disk_files.num_files_pdf}'
         )
         
     def add_files_sheets(self):
-        self.controller.controllerFiles.select_files(LibraryDocs.SHEET)
-        self.lb_pdf.config(
-            text=f'Planilhas: {self.controller.controllerFiles.num_files_sheet}'
+        self.select_disk_files.select_files(LibraryDocs.SHEET)
+        self.lb_sheets.config(
+            text=f'Planilhas: {self.select_disk_files.num_files_sheet}'
         )
 
     def add_files_image(self):
-        self.controller.controllerFiles.select_files(LibraryDocs.IMAGE)
+        self.select_disk_files.select_files(LibraryDocs.IMAGE)
         self.lb_img.config(
-            text=f' Images: {self.controller.controllerFiles.num_files_image}'
+            text=f' Images: {self.select_disk_files.num_files_image}'
         )
 
     def add_folder(self):
-        self.controller.controllerFiles.select_dir(LibraryDocs.ALL_DOCUMENTS)
+        self.select_disk_files.select_dir(LibraryDocs.ALL_DOCUMENTS)
         self.lb_pdf.config(
-            text=f'PDFs: {self.controller.controllerFiles.num_files_pdf}'
+            text=f'PDFs: {self.select_disk_files.num_files_pdf}'
         )
         self.lb_img.config(
-            text=f' Images: {self.controller.controllerFiles.num_files_image}'
+            text=f' Images: {self.select_disk_files.num_files_image}'
         )
         self.lb_sheets.config(
-            text=f'Planilhas: {self.controller.controllerFiles.num_files_sheet}'
+            text=f'Planilhas: {self.select_disk_files.num_files_sheet}'
         )
 
     def select_ouput_folder(self):
-        self.controller.controllerFiles.select_output_dir()
+        self.controller.controller_conf.select_output_dir()
         self.lb_outdir.config(
-            text=f'Salvar em: {self.controller.controllerFiles.save_dir.basename()}'
+            text=f'Salvar em: {self.controller.controller_conf.save_dir.basename()}'
         )
 
     def clear_files(self):
         """Limpar a lista de arquivos selecionados"""
-        self.controller.controllerFiles.clear()
-
+        self.controller.controller_conf.clear()
+        self.select_disk_files.clear()
         self.lb_pdf.config(
-            text=f'PDFs: {self.controller.controllerFiles.num_files_pdf}'
+            text=f'PDFs: {self.select_disk_files.num_files_pdf}'
         )
         self.lb_img.config(
-            text=f'Imagens: {self.controller.controllerFiles.num_files_image}'
+            text=f'Imagens: {self.select_disk_files.num_files_image}'
         )
         self.lb_sheets.config(
-            text=f'Planilhas: {self.controller.controllerFiles.num_files_sheet}'
+            text=f'Planilhas: {self.select_disk_files.num_files_sheet}'
         )
 
 
-
 class WidgetExportFiles(object):
+
     def __init__(self, frame: ttk.Frame, *, orientation: Orientation = Orientation.V, controller: ControllerApp):
         self.controller: ControllerApp = controller
         self.orientation: Orientation = orientation
@@ -434,7 +445,6 @@ class WidgetExportFiles(object):
             self.btn_sheets.pack(expand=True, fill='both', padx=1, pady=1, side=tk.LEFT)
         self.btn_sheets.config(command=on_click)
             
-   
 
 class WidgetScrow(object):
     def __init__(self, frame: ttk.Frame, *, width:int = 48, height: int = 8):
@@ -480,11 +490,10 @@ class WidgetProgressBar(object):
     """
     def __init__(
                     self, 
-                    frame:ttk.Frame, 
-                    *, 
+                    frame: ttk.Frame, *,
                     mode: LibProgress = LibProgress.INDETERMINATE, 
-                    orientation:str='horizontal', 
-                    default_text:str='0%',
+                    orientation: str = 'horizontal',
+                    default_text: str = '0%',
                     theme: AppThemes = AppThemes.PBAR_GREEN,
                 ):
         """Barra de progresso."""
@@ -513,31 +522,31 @@ class WidgetProgressBar(object):
         self._pbar.pack(expand=True, fill='x', padx=1, pady=1)
         
         if self.mode == LibProgress.INDETERMINATE:
-            self.implement_pbar:ProgressBarTkIndeterminate =  ProgressBarTkIndeterminate(
+            self.implement_pbar = ProgressBarTkIndeterminate(
                 label_text=self._label_text,
                 label_progress=self._label_progress,
                 progress_bar=self._pbar,
             )
         elif self.mode == LibProgress.DETERMINATE:
-            self.implement_pbar:ProgressBarTkDeterminate =  ProgressBarTkDeterminate(
+            self.implement_pbar = ProgressBarTkDeterminate(
                 label_text=self._label_text,
                 label_progress=self._label_progress,
                 progress_bar=self._pbar,
             )
         else:
             raise ValueError(f'{__class__.__name__} Use: determinate OU indeterminate')
-        self.progress_adapter:ProgressBarAdapter = ProgressBarAdapter(self.implement_pbar)
+        self.progress_adapter: ProgressBarAdapter = ProgressBarAdapter(self.implement_pbar)
         
-    def update(self, prog:float, text:str):
+    def update(self, prog: float, text: str):
         self.progress_adapter.update(prog, text)
         
-    def update_text(self, text:str):
+    def update_text(self, text: str):
         self.progress_adapter.update_text(text)
         
     def update_percent(self, prog: float):
         self.progress_adapter.update_percent(prog)
         
-    def get_progress(self) -> int:
+    def get_progress(self) -> float:
         return self.progress_adapter.get_current_percent()
     
     def start(self):
