@@ -38,7 +38,7 @@ class PageConvertSheet(UiPage):
         super().__init__(controller=controller)
         self.controller: Controller = controller
         self.controller.add_observer(self)
-        self.controller.controllerFiles.add_observer(self)
+        self.controller.controller_conf.add_observer(self)
         self.PAGE_NAME = 'Planilhas'
         self.PAGE_ROUTE = '/home/sheets'
         self.GEOMETRY = '630x520'
@@ -55,7 +55,7 @@ class PageConvertSheet(UiPage):
         self.initUI()
         # Inscrever-se no notificador de arquivos
         # e notificador de tema/estilo
-        self.controller.controllerFiles.add_observer(self)
+        self.controller.controller_conf.add_observer(self)
         self.controller.appPrefs.add_observer(self) # Preferências do usuário.
         self.controller.appPrefs.send_notify()
         #===========================================================#
@@ -107,6 +107,7 @@ class PageConvertSheet(UiPage):
             self.frame_input, 
             controller=self.controller,
             orientation=Orientation.H,
+            disk_files=self.select_disk_files,
         )
         self.w_row_files.set_button_sheets()
         self.w_row_files.set_button_clear()
@@ -384,7 +385,7 @@ class PageConvertSheet(UiPage):
     def _run_export_current_data_multi(self):
         col = self.combobox_columns.get()
         values = self.data[col].drop_duplicates().values.tolist()
-        out_dir: Directory = self.controller.controllerFiles.save_dir.concat('Exportado', create=True)
+        out_dir: Directory = self.controller.controller_conf.save_dir.concat('Exportado', create=True)
         max_values = len(values)
         self.pbar.start()
         self.scrow.clear()
@@ -404,7 +405,7 @@ class PageConvertSheet(UiPage):
         self.thread_main_stop()
     
     def _run_export_current_data(self):
-        output_file: File = self.controller.controllerFiles.save_dir.join_file('output_data.xlsx')
+        output_file: File = self.controller.controller_conf.save_dir.join_file('output_data.xlsx')
         self.pbar.start()
         self.pbar.update(0, f'Exportando arquivo: {output_file.basename()}')
         self.data.to_excel(output_file.absolute(), index=False)
@@ -420,7 +421,7 @@ class PageConvertSheet(UiPage):
         if not current_column in self.data.columns.tolist():
             messagebox.showerror('Coluna não encontrada', f'A coluna {current_column} não existe no dado atual!')
             return
-        output_path: File = self.controller.controllerFiles.save_dir.join_file(f'output-{current_column}.xlsx')
+        output_path: File = self.controller.controller_conf.save_dir.join_file(f'output-{current_column}.xlsx')
         self.pbar.update(0, f'Exportando coluna {current_column}')
         df = self.data[[current_column]]
         df = df.drop_duplicates()
@@ -469,7 +470,7 @@ class PageConvertSheet(UiPage):
         self.data = df_filter.astype('str')
         
     def open_file_filter(self):
-        file: str = self.controller.controllerFiles.fileDialog.open_file_sheet()
+        file: str = self.controller.controller_conf.fileDialog.open_file_sheet()
         if (file is None) or (file == ''):
             return
         self.file_sheet_filter = File(file)
@@ -519,7 +520,7 @@ class PageConvertSheet(UiPage):
             Alterar a propriedade que contém o DataFrame atual
         com base no arquivo selecionado na combobox.
         """
-        if self.controller.controllerFiles.num_files_sheet == 0:
+        if self.controller.controller_conf.num_files_sheet == 0:
             messagebox.showinfo('Aviso', 'Adicione planilhas para prosseguir!')
             return
         self.thread_main_create(self._run_set_current_data_frame)
@@ -528,7 +529,7 @@ class PageConvertSheet(UiPage):
         current_file_name: str = self.combobox_files_names.get()
         selected_sheet_name: SheetName = self.combobox_sheet_names.get()
         if not current_file_name in self.filenames_paths:
-            file_path: File = self.controller.controllerFiles.get_files_sheets()[0]
+            file_path: File = self.controller.controller_conf.get_files_sheets()[0]
             selected_sheet_name = None
         else:
             file_path: File = self.filenames_paths[current_file_name]
@@ -576,7 +577,7 @@ class PageConvertSheet(UiPage):
     def _run_update_sheet_names(self):
         self.pbar.start()
         self.pbar.update(0, f'Atualizando aguarde.')
-        files = self.controller.controllerFiles.get_files_sheets()
+        files = self.controller.controller_conf.get_files_sheets()
         maxnum: int = len(files)
         for num, file in enumerate(files):
             self.pbar.update(
@@ -613,7 +614,7 @@ class PageConvertSheet(UiPage):
         alterou a seleção de arquivos, limpar ou adicionar. Sendo necessário
         atualizar as propriedades de DataFrame e arquivos.
         """
-        if self.controller.controllerFiles.numFiles == 0:
+        if self.controller.controller_conf.numFiles == 0:
             # O usuário limpou os arquivos
             self.filesnames_data_frame.clear()
             self.filenames_paths.clear()
@@ -657,7 +658,12 @@ class PageFilesToExcel(UiPage):
         self.frameWidgets = ttk.Frame(self)
         self.frameWidgets.pack(expand=True, fill='both', padx=1, pady=1)
 
-        self.w_files = WidgetFiles(self.frameWidgets, controller=self.controller, orientation=Orientation.V)
+        self.w_files = WidgetFiles(
+            self.frameWidgets,
+            controller=self.controller,
+            orientation=Orientation.V,
+            disk_files=self.select_disk_files,
+        )
         self.w_files.set_button_image()
         self.w_files.set_button_pdf()
         self.w_files.set_button_sheets()
@@ -698,7 +704,7 @@ class PageFilesToExcel(UiPage):
         self.pbar.start()
         self.pbar.update_text('Exporando planilha!')
         data: pd.DataFrame = self.__get_info_files()
-        data.to_excel(self.controller.controllerFiles.save_dir.join_file('Arquivos.xlsx').absolute(), index=False)
+        data.to_excel(self.controller.controller_conf.save_dir.join_file('Arquivos.xlsx').absolute(), index=False)
         self.topBar.set_text('Planilha exportada!')
         self.pbar.update(100, 'OK')
         self.pbar.stop()
@@ -708,7 +714,7 @@ class PageFilesToExcel(UiPage):
         """
             Obter uma lista de com os nomes dos arquivos selecionados pelo usuário.
         """
-        files: List[File] = self.controller.controllerFiles.files
+        files: List[File] = self.controller.controller_conf.files
         files.sort(key=lambda file: file.absolute().lower())
         self.topBar.pbar.update_text('Obtendo dados')
         data = {
@@ -740,7 +746,7 @@ class PageMoveFiles(UiPage):
     def __init__(self, *, controller: Controller):
         super().__init__(controller=controller)
         self.controller: Controller = controller
-        self.controller.controllerFiles.add_observer(self)
+        self.controller.controller_conf.add_observer(self)
         self.PAGE_ROUTE = '/home/page_mv_files'
         self.PAGE_NAME = 'Mover Arquivos'
         self.GEOMETRY = "500x200"
@@ -792,7 +798,7 @@ class PageMoveFiles(UiPage):
         self.btn_add_sheet = ttk.Button(
             self.frameButtons,
             text='Adicionar planilha',
-            command=lambda: self.controller.controllerFiles.select_file(LibraryDocs.EXCEL),
+            command=lambda: self.controller.controller_conf.select_file(LibraryDocs.EXCEL),
             style=AppThemes.BUTTON_GREEN.value,
             width=20,
         )
@@ -824,7 +830,7 @@ class PageMoveFiles(UiPage):
 
     def _run_update_files(self):
         self.topBar.set_text('Atualizando DataFrame')
-        files = self.controller.controllerFiles.get_files_excel()
+        files = self.controller.controller_conf.get_files_excel()
         maxnum = len(files)
         if maxnum == 0:
             return
